<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\gymat\Customizer\Settings;

use radiustheme\gymat\Customizer\GymatTheme_Customizer;
use radiustheme\gymat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class GymatTheme_Class_Post_Settings extends GymatTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_class_post_controls' ) );
	}

    /**
     * Gallery Post Controls
     */
    public function register_class_post_controls( $wp_customize ) {
		
		$wp_customize->add_setting( 'class_style',
            array(
                'default' => $this->defaults['class_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'class_style',
            array(
                'label' => __( 'Class Archive Layout', 'gymat' ),
                'description' => esc_html__( 'Select the Class layout for class page', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'choices' => array(
                    'style1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/post-style-1.png',
                        'name' => __( 'Layout 1', 'gymat' )
                    ),
                    'style2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/post-style-3.png',
                        'name' => __( 'Layout 2', 'gymat' )
                    ),
                )
            )
        ) );
                    

        // Schedule Time Format
        $wp_customize->add_setting( 'class_time_format',
            array(
                'default' => $this->defaults['class_time_format'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'class_time_format',
            array(
                'label' => __( 'Schedule Time Format', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'radio',
                'choices' => array(
                    '12' => esc_html__( '12-hour', 'gymat' ),
                    '24' => esc_html__( '24-hour', 'gymat' ),
                ),
            )
        );

        // Columns Width
        $wp_customize->add_setting( 'class_grid1_cols',
            array(
                'default' => $this->defaults['class_grid1_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_class_grid1_enabled',
            )
        );
        $wp_customize->add_control( 'class_grid1_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'select',
                'choices' => array(
                    '12' => esc_html__( '1 Columns', 'gymat' ),
                    '6' => esc_html__( '2 Columns', 'gymat' ),
                    '4' => esc_html__( '3 Columns', 'gymat' ),
                    '3' => esc_html__( '4 Columns', 'gymat' ),
                    '2' => esc_html__( '6 Columns', 'gymat' ),
                ),
                'active_callback' => 'rttheme_class_grid1_enabled',
            )
        );

        $wp_customize->add_setting( 'class_grid2_cols',
            array(
                'default' => $this->defaults['class_grid2_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_class_grid2_enabled',
            )
        );
        $wp_customize->add_control( 'class_grid2_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'select',
                'choices' => array(
                    '12' => esc_html__( '1 Columns', 'gymat' ),
                    '6' => esc_html__( '2 Columns', 'gymat' ),
                    '4' => esc_html__( '3 Columns', 'gymat' ),
                    '3' => esc_html__( '4 Columns', 'gymat' ),
                    '2' => esc_html__( '6 Columns', 'gymat' ),
                ),
                'active_callback' => 'rttheme_class_grid2_enabled',
            )
        );

        // Gallery option
        $wp_customize->add_setting( 'class_excerpt_limit',
            array(
                'default' => $this->defaults['class_excerpt_limit'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'class_excerpt_limit',
            array(
                'label' => __( 'Class Content Limit', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'number',
            )
        );
		
		$wp_customize->add_setting( 'class_ar_icon',
            array(
                'default' => $this->defaults['class_ar_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
                'active_callback' => 'rttheme_class_grid1_enabled',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'class_ar_icon',
            array(
                'label' => __( 'Class Icon', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'active_callback' => 'rttheme_class_grid1_enabled',
            )
        ));

        $wp_customize->add_setting( 'class_ar_button',
            array(
                'default' => $this->defaults['class_ar_button'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
                'active_callback' => 'rttheme_class_grid2_enabled',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'class_ar_button',
            array(
                'label' => __( 'Join Now Button', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'active_callback' => 'rttheme_class_grid2_enabled',
            )
        ));
			
		
		$wp_customize->add_setting('class_single_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'class_single_heading', array(
            'label' => __( 'Single Class', 'gymat' ),
            'section' => 'rttheme_class_settings',
        )));

        $wp_customize->add_setting( 'single_class_ar_info',
            array(
                'default' => $this->defaults['single_class_ar_info'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'single_class_ar_info',
            array(
                'label' => __( 'Class Info', 'gymat' ),
                'section' => 'rttheme_class_settings',
            )
        ));

        $wp_customize->add_setting( 'single_class_ar_button',
            array(
                'default' => $this->defaults['single_class_ar_button'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'single_class_ar_button',
            array(
                'label' => __( 'Join Now Button', 'gymat' ),
                'section' => 'rttheme_class_settings',
            )
        ));

        
		// Related Gallery Post
		$wp_customize->add_setting('class_related_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'class_related_heading', array(
            'label' => __( 'Related Class Settings', 'gymat' ),
            'section' => 'rttheme_class_settings',
        )));
		
		$wp_customize->add_setting( 'show_related_class',
            array(
                'default' => $this->defaults['show_related_class'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'show_related_class',
            array(
                'label' => __( 'Show Related Class', 'gymat' ),
                'section' => 'rttheme_class_settings',
            )
        ));
		
		$wp_customize->add_setting( 'class_related_title',
            array(
                'default' => $this->defaults['class_related_title'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'class_related_title',
            array(
                'label' => __( 'Related Title', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'text',
				'active_callback'   => 'rttheme_is_related_class_enabled',
            )
        );
		
		
		
		
		$wp_customize->add_setting( 'related_class_number',
            array(
                'default' => $this->defaults['related_class_number'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'related_class_number',
            array(
                'label' => __( 'Class Post', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'number',
				'active_callback'   => 'rttheme_is_related_class_enabled',
            )
        );
		
		$wp_customize->add_setting( 'related_class_title_limit',
            array(
                'default' => $this->defaults['related_class_title_limit'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'related_class_title_limit',
            array(
                'label' => __( 'Title Limit', 'gymat' ),
                'section' => 'rttheme_class_settings',
                'type' => 'number',
				'active_callback'   => 'rttheme_is_related_class_enabled',
            )
        );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new GymatTheme_Class_Post_Settings();
}
