<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\gymat\Customizer\Settings;

use radiustheme\gymat\Customizer\GymatTheme_Customizer;
use radiustheme\gymat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class GymatTheme_Footer_Settings extends GymatTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_footer_controls' ) );
	}

    public function register_footer_controls( $wp_customize ) {
		
		// Footer off & on
		$wp_customize->add_setting( 'footer_area',
            array(
                'default' => $this->defaults['footer_area'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'footer_area',
            array(
                'label' => __( 'Footer On/Off', 'gymat' ),
                'section' => 'footer_section',
            )
        ) );

        $wp_customize->add_setting( 'footer_copyright_area',
            array(
                'default' => $this->defaults['footer_copyright_area'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'footer_copyright_area',
            array(
                'label' => __( 'Footer Copyright', 'gymat' ),
                'section' => 'footer_section',
            )
        ) );

        // Footer Style
        $wp_customize->add_setting( 'footer_style',
            array(
                'default' => $this->defaults['footer_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );

        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'footer_style',
            array(
                'label' => __( 'Footer Layout', 'gymat' ),
                'description' => esc_html__( 'You can set default footer form here.', 'gymat' ),
                'section' => 'footer_section',
                'choices' => gymat_footer_layout()
            )
        ) );
		// Footer column
		$wp_customize->add_setting( 'footer_column_1',
            array(
                'default' => $this->defaults['footer_column_1'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'footer_column_1',
            array(
                'label' => __( 'Number of Columns for Footer', 'gymat' ),
                'section' => 'footer_section',
                'type' => 'select',
                'choices' => array(
                    '1' => esc_html__( '1 Column', 'gymat' ),
                    '2' => esc_html__( '2 Columns', 'gymat' ),
                    '3' => esc_html__( '3 Columns', 'gymat' ),
                    '4' => esc_html__( '4 Columns', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer1_footer2_footer4_enable_condition',
            )
        );
        //footer 3 3 column option
        $wp_customize->add_setting( 'footer_column_2',
            array(
                'default' => $this->defaults['footer_column_2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'footer_column_2',
            array(
                'label' => __( 'Number of Columns for Footer', 'gymat' ),
                'section' => 'footer_section',
                'type' => 'select',
                'choices' => array(
                    '1' => esc_html__( '1 Column', 'gymat' ),
                    '2' => esc_html__( '2 Columns', 'gymat' ),
                    '3' => esc_html__( '3 Columns', 'gymat' ),
                    '4' => esc_html__( '4 Columns', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer3_enable_condition',
            )
        );

		// Footer bgtype
		$wp_customize->add_setting( 'footer_bgtype',
            array(
                'default' => $this->defaults['footer_bgtype'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_footer1_enable_condition',
            )
        );
        $wp_customize->add_control( 'footer_bgtype',
            array(
                'label' => __( 'Banner Background Type', 'gymat' ),
                'section' => 'footer_section',
                'description' => esc_html__( 'This is banner background type.', 'gymat' ),
                'type' => 'select',
                'choices' => array(
					'fbgcolor' => esc_html__( 'BG Color', 'gymat' ),
                    'fbgimg' => esc_html__( 'BG Image', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer1_enable_condition',
            )
        );
        // Footer  bgtype 2 .it is used for footer 2 and  3 
		$wp_customize->add_setting( 'footer_bgtype2',
            array(
                'default' => $this->defaults['footer_bgtype2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_is_footer2_footer3_enabled',
            )
        );
        $wp_customize->add_control( 'footer_bgtype2',
            array(
                'label' => __( 'Banner Background Type', 'gymat' ),
                'section' => 'footer_section',
                'description' => esc_html__( 'This is banner background type.', 'gymat' ),
                'type' => 'select',
                'choices' => array(
                    'fbgcolor2' => esc_html__( 'BG Color', 'gymat' ),
                    'fbgimg2' => esc_html__( 'BG Image', 'gymat' ),
                ),
                'active_callback' => 'rttheme_is_footer2_footer3_enabled',
            )
        );
		// Footer background color
        $wp_customize->add_setting('fbgcolor', 
            array(
                'default' => $this->defaults['fbgcolor'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_footer_bgcolor_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fbgcolor',
            array(
                'label' => esc_html__('Footer Background Color', 'gymat'),
                'settings' => 'fbgcolor', 
                'section' => 'footer_section', 
                'active_callback' => 'rttheme_footer_bgcolor_type_condition',
            )
        ));

        // Footer background color for bgtype2. It is used for footer 2 and footer 3
        $wp_customize->add_setting('fbgcolor2', 
            array(
                'default' => $this->defaults['fbgcolor2'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_footer2_footer3_bgcolor_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fbgcolor2',
            array(
                'label' => esc_html__('Footer Background Color', 'gymat'),
                'settings' => 'fbgcolor2', 
                'section' => 'footer_section', 
                'active_callback' => 'rttheme_footer2_footer3_bgcolor_type_condition',
            )
        ));

        // Footer overley color
        $wp_customize->add_setting('foverlay', 
            array(
                'default' => $this->defaults['foverlay'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_footer_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'foverlay',
            array(
                'label' => esc_html__('Footer Overlay Color', 'gymat'),
                'settings' => 'foverlay', 
                'section' => 'footer_section', 
                'active_callback' => 'rttheme_footer_bgimg_type_condition',
            )
        ));
		// Footer background image
		$wp_customize->add_setting( 'fbgimg',
            array(
                'default' => $this->defaults['fbgimg'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
                'active_callback' => 'rttheme_footer_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'fbgimg',
            array(
                'label' => __( 'Footer Background Image', 'gymat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'gymat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'gymat' ),
                    'change' => __( 'Change File', 'gymat' ),
                    'default' => __( 'Default', 'gymat' ),
                    'remove' => __( 'Remove', 'gymat' ),
                    'placeholder' => __( 'No file selected', 'gymat' ),
                    'frame_title' => __( 'Select File', 'gymat' ),
                    'frame_button' => __( 'Choose File', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer_bgimg_type_condition',
            )
        ) );


        // Footer background image for bgtype2.it is used for footer 2 and footer 3
		$wp_customize->add_setting( 'fbgimg2',
            array(
                'default' => $this->defaults['fbgimg2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
                'active_callback' => 'rttheme_footer2_footer3_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'fbgimg2',
            array(
                'label' => __( 'Footer Background Image', 'gymat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'gymat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'gymat' ),
                    'change' => __( 'Change File', 'gymat' ),
                    'default' => __( 'Default', 'gymat' ),
                    'remove' => __( 'Remove', 'gymat' ),
                    'placeholder' => __( 'No file selected', 'gymat' ),
                    'frame_title' => __( 'Select File', 'gymat' ),
                    'frame_button' => __( 'Choose File', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer2_footer3_bgimg_type_condition',
            )
        ) );
		
		// Footer shape
		$wp_customize->add_setting( 'footer_shape',
            array(
                'default' => $this->defaults['footer_shape'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'footer_shape',
            array(
                'label' => __( 'Footer Shape', 'gymat' ),
                'section' => 'footer_section',
            )
        ) );

        // Footer shape
		$wp_customize->add_setting( 'footer_sticky',
        array(
                'default' => $this->defaults['footer_sticky'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'footer_sticky',
            array(
                'label' => __( 'Footer Sticky', 'gymat' ),
                'section' => 'footer_section',
            )
        ) );

        // Footer social
        if(class_exists('Gymat_Core')){
            $wp_customize->add_setting( 'footer_social',
            array(
                    'default' => $this->defaults['footer_social'],
                    'transport' => 'refresh',
                    'sanitize_callback' => 'rttheme_switch_sanitization',
                    'active_callback' => 'rttheme_footer1_enable_condition',
                )
            );
            $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'footer_social',
                array(
                    'label' => __( 'Footer Social', 'gymat' ),
                    'section' => 'footer_section',
                    'active_callback' => 'rttheme_footer1_enable_condition',
                )
            ) );
        }
        // Footer Logo image
		$wp_customize->add_setting( 'footer_logo',
        array(
            'default' => $this->defaults['footer_logo'],
            'transport' => 'refresh',
            'sanitize_callback' => 'absint',
            'active_callback' => 'rttheme_footer1_enable_condition',
        )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer_logo',
            array(
                'label' => __( 'Footer Logo', 'gymat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'gymat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'gymat' ),
                    'change' => __( 'Change File', 'gymat' ),
                    'default' => __( 'Default', 'gymat' ),
                    'remove' => __( 'Remove', 'gymat' ),
                    'placeholder' => __( 'No file selected', 'gymat' ),
                    'frame_title' => __( 'Select File', 'gymat' ),
                    'frame_button' => __( 'Choose File', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer1_enable_condition',
            )
        ) );

        $wp_customize->add_setting('footer_logo_text_color', 
            array(
                'default' => $this->defaults['footer_logo_text_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_footer1_enable_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_logo_text_color',
            array(
                'label' => esc_html__('Footer Logo Text Color', 'gymat'),
                'section' => 'footer_section',
                'active_callback' => 'rttheme_footer1_enable_condition', 
            )
        ));

		$wp_customize->add_setting('footer_title_color', 
            array(
                'default' => $this->defaults['footer_title_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_title_color',
            array(
                'label' => esc_html__('Footer Title Color', 'gymat'),
                'section' => 'footer_section', 
            )
        ));
		
		$wp_customize->add_setting('footer_color', 
            array(
                'default' => $this->defaults['footer_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_color',
            array(
                'label' => esc_html__('Footer Text Color', 'gymat'),
                'section' => 'footer_section', 
            )
        ));
		
		$wp_customize->add_setting('footer_link_color', 
            array(
                'default' => $this->defaults['footer_link_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_link_color',
            array(
                'label' => esc_html__('Footer Link Color', 'gymat'),
                'section' => 'footer_section', 
            )
        ));
		
		$wp_customize->add_setting('footer_link_hover_color', 
            array(
                'default' => $this->defaults['footer_link_hover_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_link_hover_color',
            array(
                'label' => esc_html__('Footer Link Hover Color', 'gymat'),
                'section' => 'footer_section', 
            )
        ));
        
		// Copyright Text
        $wp_customize->add_setting( 'copyright_text',
            array(
                'default' => $this->defaults['copyright_text'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_textarea_sanitization'
            )
        );
        $wp_customize->add_control( 'copyright_text',
            array(
                'label' => __( 'Copyright Text', 'gymat' ),
                'section' => 'footer_section',
                'type' => 'textarea',
            )
        );
        //Payment Image show/hide
        // Footer social
       
        $wp_customize->add_setting( 'payment_image_show',
        array(
                'default' => $this->defaults['payment_image_show'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'payment_image_show',
            array(
                'label' => __( 'Payment Image', 'gymat' ),
                'section' => 'footer_section',
                'active_callback' => 'rttheme_footer4_enable_condition',
            )
        ) );
        
        // Payment Image
		$wp_customize->add_setting( 'payment_image',
        array(
            'default' => $this->defaults['payment_image'],
            'transport' => 'refresh',
            'sanitize_callback' => 'absint',
        )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'payment_image',
            array(
                'label' => __( 'Payment Image', 'gymat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'gymat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'gymat' ),
                    'change' => __( 'Change File', 'gymat' ),
                    'default' => __( 'Default', 'gymat' ),
                    'remove' => __( 'Remove', 'gymat' ),
                    'placeholder' => __( 'No file selected', 'gymat' ),
                    'frame_title' => __( 'Select File', 'gymat' ),
                    'frame_button' => __( 'Choose File', 'gymat' ),
                ),
                'active_callback' => 'rttheme_footer4_enable_condition',
            )
        ) );
    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new GymatTheme_Footer_Settings();
}
