<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\gymat\Customizer\Settings;

use radiustheme\gymat\Customizer\GymatTheme_Customizer;
use radiustheme\gymat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class GymatTheme_Gallery_Post_Settings extends GymatTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_gallery_post_controls' ) );
	}

    /**
     * Gallery Post Controls
     */
    public function register_gallery_post_controls( $wp_customize ) {
		
		// Columns Width
        $wp_customize->add_setting( 'gallery_grid_cols',
            array(
                'default' => $this->defaults['gallery_grid_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'gallery_grid_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'gymat' ),
                'section' => 'rttheme_gallery_settings',
                'type' => 'select',
                'choices' => array(
                    '12' => esc_html__( '1 Columns', 'gymat' ),
                    '6' => esc_html__( '2 Columns', 'gymat' ),
                    '4' => esc_html__( '3 Columns', 'gymat' ),
                    '3' => esc_html__( '4 Columns', 'gymat' ),
                    '2' => esc_html__( '6 Columns', 'gymat' ),
                ),
            )
        );

        // Gallery option
        $wp_customize->add_setting( 'gallery_arexcerpt_limit',
            array(
                'default' => $this->defaults['gallery_arexcerpt_limit'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'gallery_arexcerpt_limit',
            array(
                'label' => __( 'Gallery Content Limit', 'gymat' ),
                'section' => 'rttheme_gallery_settings',
                'type' => 'number',
            )
        );
		
		$wp_customize->add_setting( 'gallery_ar_category',
            array(
                'default' => $this->defaults['gallery_ar_category'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'gallery_ar_category',
            array(
                'label' => __( 'Show Category', 'gymat' ),
                'section' => 'rttheme_gallery_settings',
            )
        ));
		
		$wp_customize->add_setting( 'gallery_ar_excerpt',
            array(
                'default' => $this->defaults['gallery_ar_excerpt'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'gallery_ar_excerpt',
            array(
                'label' => __( 'Show Excerpt', 'gymat' ),
                'section' => 'rttheme_gallery_settings',
            )
        ));
		
		$wp_customize->add_setting( 'gallery_ar_link',
            array(
                'default' => $this->defaults['gallery_ar_link'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'gallery_ar_link',
            array(
                'label' => __( 'Show Link', 'gymat' ),
                'section' => 'rttheme_gallery_settings',
            )
        ));
		
    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new GymatTheme_Gallery_Post_Settings();
}
