<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\gymat\Customizer\Settings;

use radiustheme\gymat\Customizer\GymatTheme_Customizer;
use radiustheme\gymat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class GymatTheme_Header_Settings extends GymatTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_header_controls' ) );
	}

    public function register_header_controls( $wp_customize ) {
		
		// Top Bar Style
		$wp_customize->add_setting( 'top_bar',
            array(
                'default' => $this->defaults['top_bar'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'top_bar',
            array(
                'label' => __( 'Top Bar On/Off', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		
        $wp_customize->add_setting( 'top_bar_style',
            array(
                'default' => $this->defaults['top_bar_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'top_bar_style',
            array(
                'label' => __( 'Top Bar Layout', 'gymat' ),
                'description' => esc_html__( 'You can override this settings only Mobile', 'gymat' ),
                'section' => 'header_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/topbar.jpg',
                        'name' => __( 'Layout 1', 'gymat' )
                    ),
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/topbar.jpg',
                        'name' => __( 'Layout 2', 'gymat' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/topbar-3.jpg',
                        'name' => __( 'Layout 3', 'gymat' )
                    ),
                    '4' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/topbar-4.jpg',
                        'name' => __( 'Layout 4', 'gymat' )
                    )                 
                )
            )
        ) );
		// Topbar one option
		$wp_customize->add_setting('top_bar_bgcolor', 
            array(
                'default' => $this->defaults['top_bar_bgcolor'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_bgcolor',
            array(
                'label' => esc_html__('Top Bar Background Color', 'gymat'),
                'section' => 'header_section', 
				
            )
        ));
		
		$wp_customize->add_setting('top_bar_color', 
            array(
                'default' => $this->defaults['top_bar_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_color',
            array(
                'label' => esc_html__('Top Bar Text Color', 'gymat'),
                'section' => 'header_section', 
            )
        ));
		$wp_customize->add_setting('top_bar_icon_color', 
            array(
                'default' => $this->defaults['top_bar_icon_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_icon_color',
            array(
                'label' => esc_html__('Top Bar Icon Color', 'gymat'),
                'section' => 'header_section', 
            )
        ));
        
    
        /**
         * Heading for Header Variation
         */
        $wp_customize->add_setting('header_variation_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'header_variation_heading', array(
            'label' => __( 'Header Variation', 'gymat' ),
            'section' => 'header_section',
        )));
		
		$wp_customize->add_setting( 'mobile_header_menu',
            array(
                'default' => $this->defaults['mobile_header_menu'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_menu',
            array(
                'label' => __( 'Sticky Header', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		
		$wp_customize->add_setting( 'tr_header',
            array(
                'default' => $this->defaults['tr_header'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'tr_header',
            array(
                'label' => __( 'Transparent Header', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		
		$wp_customize->add_setting( 'header_opt',
            array(
                'default' => $this->defaults['header_opt'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'header_opt',
            array(
                'label' => __( 'Header On/Off', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		
        // Header Style
        $wp_customize->add_setting( 'header_style',
            array(
                'default' => $this->defaults['header_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'header_style',
            array(
                'label' => __( 'Header Layout', 'gymat' ),
                'description' => esc_html__( 'You can override this settings only Mobile', 'gymat' ),
                'section' => 'header_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-1.jpg',
                        'name' => __( 'Layout 1', 'gymat' )
                    ),                  
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-2.jpg',
                        'name' => __( 'Layout 2', 'gymat' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-3.jpg',
                        'name' => __( 'Layout 3', 'gymat' )
                    ),
                    '4' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-4.jpg',
                        'name' => __( 'Layout 4', 'gymat' )
                    ),
                    
                    '5' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-5.jpg',
                        'name' => __( 'Layout 5', 'gymat' )
                    ),
                )
            )
        ) );
        
        //Header Action
		$wp_customize->add_setting( 'search_icon',
            array(
                'default' => $this->defaults['search_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'search_icon',
            array(
                'label' => __( 'Search Icon', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		$wp_customize->add_setting( 'cart_icon',
            array(
                'default' => $this->defaults['cart_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'cart_icon',
            array(
                'label' => __( 'Cart Icon', 'neeon' ),
                'section' => 'header_section',
            )
        ) );
		$wp_customize->add_setting( 'vertical_menu_icon',
            array(
                'default' => $this->defaults['vertical_menu_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'vertical_menu_icon',
            array(
                'label' => __( 'Vertical Menu Icon', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		      
		$wp_customize->add_setting( 'online_button',
            array(
                'default' => $this->defaults['online_button'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'online_button',
            array(
                'label' => __( 'Make a Claim Button', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
		
		$wp_customize->add_setting( 'online_button_text',
            array(
                'default' => $this->defaults['online_button_text'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
				'active_callback'   => 'rttheme_is_claim_enabled',
            )
        );
        $wp_customize->add_control( 'online_button_text',
            array(
                'label' => __( 'Button Text', 'gymat' ),
                'section' => 'header_section',
                'type' => 'text',
				'active_callback'   => 'rttheme_is_claim_enabled',
            )
        );
		
		$wp_customize->add_setting( 'online_button_link',
            array(
                'default' => $this->defaults['online_button_link'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_url_sanitization',
				'active_callback'   => 'rttheme_is_claim_enabled',
            )
        );
        $wp_customize->add_control( 'online_button_link',
            array(
                'label' => __( 'Button Link', 'gymat' ),
                'section' => 'header_section',
                'type' => 'url',
				'active_callback'   => 'rttheme_is_claim_enabled',
            )
        );


        $wp_customize->add_setting( 'header_location_txt',
        array(
            'default' => $this->defaults['header_location_txt'],
            'transport' => 'refresh',
            'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_location_txt',
            array(
                'label' => __( 'Header "Location" Text', 'gymat' ),
                'section' => 'header_section',
                'type' => 'text',
            )
        );

        $wp_customize->add_setting( 'header_email_txt',
        array(
            'default' => $this->defaults['header_email_txt'],
            'transport' => 'refresh',
            'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_email_txt',
            array(
                'label' => __( 'Header "Email" Text', 'gymat' ),
                'section' => 'header_section',
                'type' => 'text',
            )
        );
        if(class_exists('Gymat_Core')){
            $wp_customize->add_setting( 'header_social_txt',
            array(
                'default' => $this->defaults['header_social_txt'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
                )
            );
            $wp_customize->add_control( 'header_social_txt',
                array(
                    'label' => __( 'Header "Social" Text', 'gymat' ),
                    'section' => 'header_section',
                    'type' => 'text',
                )
            );
        }
        $wp_customize->add_setting( 'header_hotline_txt',
        array(
            'default' => $this->defaults['header_hotline_txt'],
            'transport' => 'refresh',
            'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_hotline_txt',
            array(
                'label' => __( 'Header "Call" Text', 'gymat' ),
                'section' => 'header_section',
                'type' => 'text',
            )
        );

        $wp_customize->add_setting( 'topbar_text',
        array(
            'default' => $this->defaults['topbar_text'],
            'transport' => 'refresh',
            'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'topbar_text',
            array(
                'label' => __( 'Topbar Text', 'gymat' ),
                'section' => 'header_section',
                'type' => 'text',
            )
        );

		$wp_customize->add_setting('resmenu_width',
			array(
				'default'           => $this->defaults['resmenu_width'],
				'transport'         => 'refresh',
				'sanitize_callback' => 'rttheme_text_sanitization'
			)
        );
        $wp_customize->add_control('resmenu_width',
			array(
				'label'   => esc_html__('Mobile Menu Width', 'gymat'),
				'section' => 'header_section',
				'type'    => 'text'
			)
        );

        //Header Mobile

        $wp_customize->add_setting('header_mobile_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'header_mobile_heading', array(
            'label' => __( 'Mobile Header', 'gymat' ),
            'section' => 'header_section',
        )));

        $wp_customize->add_setting( 'mobile_header_menu',
            array(
                'default' => $this->defaults['mobile_header_menu'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_menu',
            array(
                'label' => __( 'Mobile Header', 'gymat' ),
                'section' => 'header_section',
            )
        ) );

       
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_text',
            array(
                'label' => __( 'Header Text', 'gymat' ),
                'section' => 'header_section',
            )
        ) );

        $wp_customize->add_setting( 'mobile_header_phone',
            array(
                'default' => $this->defaults['mobile_header_phone'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_phone',
            array(
                'label' => __( 'Header Phone', 'gymat' ),
                'section' => 'header_section',
            )
        ) );

        if(class_exists('Gymat_Core')){
            $wp_customize->add_setting( 'mobile_header_social',
                array(
                    'default' => $this->defaults['mobile_header_social'],
                    'transport' => 'refresh',
                    'sanitize_callback' => 'rttheme_switch_sanitization',
                )
            );
            $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_social',
                array(
                    'label' => __( 'Header Social', 'gymat' ),
                    'section' => 'header_section',
                )
            ) );
        }
        $wp_customize->add_setting( 'mobile_header_make_claim',
            array(
                'default' => $this->defaults['mobile_header_make_claim'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_make_claim',
            array(
                'label' => __( 'Header Make a Claim Button', 'gymat' ),
                'section' => 'header_section',
            )
        ) );
        $wp_customize->add_setting( 'mobile_header_cart_icon',
            array(
                'default' => $this->defaults['mobile_header_cart_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'mobile_header_cart_icon',
            array(
                'label' => __( 'Header Cart Icon', 'finbuzz' ),
                'section' => 'header_section',
            )
        ) );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new GymatTheme_Header_Settings();
}
