<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\gymat\Customizer\Settings;

use radiustheme\gymat\Customizer\GymatTheme_Customizer;
use radiustheme\gymat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\gymat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class GymatTheme_Trainer_Post_Settings extends GymatTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_trainer_post_controls' ) );
	}

    /**
     * Gallery Post Controls
     */
    public function register_trainer_post_controls( $wp_customize ) {
		
		$wp_customize->add_setting( 'trainer_archive_style',
            array(
                'default' => $this->defaults['trainer_archive_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'trainer_archive_style',
            array(
                'label' => __( 'Trainer Archive Layout', 'gymat' ),
                'description' => esc_html__( 'Select the gallery layout for gallery page', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'choices' => array(
                    'style1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/post-style-1.png',
                        'name' => __( 'Layout 1', 'gymat' )
                    ),
                    'style2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/post-style-3.png',
                        'name' => __( 'Layout 2', 'gymat' )
                    ),
                )
            )
        ) );

        // Gallery option
        $wp_customize->add_setting( 'trainer_arexcerpt_limit',
            array(
                'default' => $this->defaults['trainer_arexcerpt_limit'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'trainer_arexcerpt_limit',
            array(
                'label' => __( 'Trainer Archive Excerpt Limit', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'number',
            )
        );
		
		
		
		$wp_customize->add_setting( 'trainer_ar_position',
            array(
                'default' => $this->defaults['trainer_ar_position'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'trainer_ar_position',
            array(
                'label' => __( 'Show Position', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
            )
        ));
		
		$wp_customize->add_setting( 'trainer_ar_social',
            array(
                'default' => $this->defaults['trainer_ar_social'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'trainer_ar_social',
            array(
                'label' => __( 'Show Social', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
            )
        ));

        $wp_customize->add_setting( 'trainer_ar_excerpt',
            array(
                'default' => $this->defaults['trainer_ar_excerpt'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'trainer_ar_excerpt',
            array(
                'label' => __( 'Show Excerpt', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
            )
        ));

        $wp_customize->add_setting( 'trainer_ar_bg_shape',
            array(
                'default' => $this->defaults['trainer_ar_bg_shape'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
                'active_callback' => 'rttheme_trainer_grid2_enabled',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'trainer_ar_bg_shape',
            array(
                'label' => __( 'Trainer Background Shape', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'active_callback' => 'rttheme_trainer_grid2_enabled',
            )
        ));

        // Columns Width
        $wp_customize->add_setting( 'trainer_grid1_cols',
            array(
                'default' => $this->defaults['trainer_grid1_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_trainer_grid1_enabled',
            )
        );
        $wp_customize->add_control( 'trainer_grid1_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'select',
                'choices' => array(
                    '12' => esc_html__( '1 Columns', 'gymat' ),
                    '6' => esc_html__( '2 Columns', 'gymat' ),
                    '4' => esc_html__( '3 Columns', 'gymat' ),
                    '3' => esc_html__( '4 Columns', 'gymat' ),
                    '2' => esc_html__( '6 Columns', 'gymat' ),
                ),
                'active_callback' => 'rttheme_trainer_grid1_enabled',
            )
        );

        // Columns Width
        $wp_customize->add_setting( 'trainer_grid2_cols',
            array(
                'default' => $this->defaults['trainer_grid2_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_trainer_grid2_enabled',
            )
        );
        $wp_customize->add_control( 'trainer_grid2_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'select',
                'choices' => array(
                    '12' => esc_html__( '1 Columns', 'gymat' ),
                    '6' => esc_html__( '2 Columns', 'gymat' ),
                    '4' => esc_html__( '3 Columns', 'gymat' ),
                    '3' => esc_html__( '4 Columns', 'gymat' ),
                    '2' => esc_html__( '6 Columns', 'gymat' ),
                ),
                'active_callback' => 'rttheme_trainer_grid2_enabled',
            )
        );
		
		// Single Trainer Post
		$wp_customize->add_setting('trainer_single_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'trainer_single_heading', array(
            'label' => __( 'Single Trainer', 'gymat' ),
            'section' => 'rttheme_trainer_settings',
        )));

        $wp_customize->add_setting( 'trainer_skill_option',
            array(
                'default' => $this->defaults['trainer_skill_option'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'trainer_skill_option',
            array(
                'label' => __( 'Show Skill', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
            )
        ));

        $wp_customize->add_setting( 'trainer_form',
            array(
                'default' => $this->defaults['trainer_form'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'trainer_form',
            array(
                'label' => __( 'Show Form', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
            )
        ));
        $wp_customize->add_setting( 'trainer_form_title',
            array(
                'default' => $this->defaults['trainer_form_title'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'trainer_form_title',
            array(
                'label' => __( 'Form Title', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'text',
            )
        );
        $wp_customize->add_setting( 'class_schedule_title',
            array(
                'default' => $this->defaults['class_schedule_title'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'class_schedule_title',
            array(
                'label' => __( 'Class Schedule Title', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'text',
            )
        );

		// Related Trainer Post
		$wp_customize->add_setting('trainer_related_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'trainer_related_heading', array(
            'label' => __( 'Related Trainer Settings', 'gymat' ),
            'section' => 'rttheme_trainer_settings',
        )));
		
		$wp_customize->add_setting( 'show_related_trainer',
            array(
                'default' => $this->defaults['show_related_trainer'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'show_related_trainer',
            array(
                'label' => __( 'Show Related Trainer', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
            )
        ));
		
		$wp_customize->add_setting( 'trainer_related_title',
            array(
                'default' => $this->defaults['trainer_related_title'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'trainer_related_title',
            array(
                'label' => __( 'Related Title', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'text',
				'active_callback'   => 'rttheme_is_related_trainer_enabled',
            )
        );
		
		$wp_customize->add_setting( 'related_trainer_social',
            array(
                'default' => $this->defaults['related_trainer_social'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'related_trainer_social',
            array(
                'label' => __( 'Trainer Social', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
				'active_callback'   => 'rttheme_is_related_trainer_enabled',
            )
        ));
		
		$wp_customize->add_setting( 'related_trainer_position',
            array(
                'default' => $this->defaults['related_trainer_position'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'related_trainer_position',
            array(
                'label' => __( 'Trainer Position', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
				'active_callback'   => 'rttheme_is_related_trainer_enabled',
            )
        ));
		
		$wp_customize->add_setting( 'related_trainer_number',
            array(
                'default' => $this->defaults['related_trainer_number'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'related_trainer_number',
            array(
                'label' => __( 'Trainer Post', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'number',
				'active_callback'   => 'rttheme_is_related_trainer_enabled',
            )
        );
		
		$wp_customize->add_setting( 'related_trainer_title_limit',
            array(
                'default' => $this->defaults['related_trainer_title_limit'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'related_trainer_title_limit',
            array(
                'label' => __( 'Title Limit', 'gymat' ),
                'section' => 'rttheme_trainer_settings',
                'type' => 'number',
				'active_callback'   => 'rttheme_is_related_trainer_enabled',
            )
        );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new GymatTheme_Trainer_Post_Settings();
}
