<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

if ( !isset( $content_width ) ) {
	$content_width = 1200;
}

add_action('after_setup_theme', 'gymat_setup');
if ( !function_exists( 'gymat_setup' ) ) {
	function gymat_setup() {
		// Language
		load_theme_textdomain( 'gymat', GYMAT_BASE_DIR . 'languages' );

		// Theme support
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		remove_theme_support('widgets-block-editor');
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
		add_theme_support( 'post-formats', array( 'aside', 'gallery', 'video', 'audio' ) );
		add_theme_support( 'woocommerce' );
		// for gutenberg support
		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Primary Color', 'gymat' ),
				'slug' => 'gymat-primary',
				'color' => '#ff0336',
			),
			array(
				'name' => esc_html__( 'Secondary Color', 'gymat' ),
				'slug' => 'gymat-secondary',
				'color' => '#FFF5F7', 
			),
			array(
				'name' => esc_html__( 'dark gray', 'gymat' ),
				'slug' => 'gymat-button-dark-gray',
				'color' => '#111111',
			),
			array(
				'name' => esc_html__( 'light gray', 'gymat' ),
				'slug' => 'gymat-button-light-gray',
				'color' => '#a5a5a5',
			),
			array(
				'name' => esc_html__( 'white', 'gymat' ),
				'slug' => 'gymat-button-white',
				'color' => '#ffffff',
			),
		) );
		add_theme_support( 'editor-gradient-presets', array(
			array(
				'name'     => esc_html__( 'Gradient Color', 'gymat' ),
				'gradient' => 'linear-gradient(to right,#ff5e17,#fa360a)',
				'slug'     => 'gymat_gradient_color',
			),
		));	
		add_theme_support( 'editor-font-sizes', array(
			array(
				'name' => esc_html__( 'Small', 'gymat' ),
				'size' => 12,
				'slug' => 'small'
			),
			array(
				'name' => esc_html__( 'Normal', 'gymat' ),
				'size' => 16,
				'slug' => 'normal'
			),
			array(
				'name' => esc_html__( 'Large', 'gymat' ),
				'size' => 36,
				'slug' => 'large'
			),
			array(
				'name' => esc_html__( 'Huge', 'gymat' ),
				'size' => 50,
				'slug' => 'huge'
			)
		) );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support('editor-styles');	
		
		// Image sizes
		add_image_size( 'gymat-size1', 1210, 740, true );   	// fullimage
		add_image_size( 'gymat-size2', 570, 400, true );    	// blog grid addon layout 1
		add_image_size( 'gymat-size3', 825, 550, true );    	// Blog layout 2
		add_image_size( 'gymat-size4', 570, 610, true );    	
		add_image_size( 'gymat-size5', 570, 456, true );    	
		add_image_size( 'gymat-size6', 570, 742, true );    	//upcomming class image
		register_nav_menus( array(
			'primary'  => esc_html__( 'Primary', 'gymat' ),
			'header_5_left_menu'  => esc_html__( 'Header 5 Left Menu', 'gymat' ),
			'header_5_right_menu'  => esc_html__( 'Header 5 Right Menu', 'gymat' ),
		) );		
	}
}

function gymat_theme_add_editor_styles() {
	add_editor_style( get_stylesheet_uri() );
}
add_action( 'admin_init', 'gymat_theme_add_editor_styles' );

function gymat_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'gymat_pingback_header' );

// Footer Html
add_action( 'wp_footer', 'gymat_footer_html', 1 );
if( !function_exists( 'gymat_footer_html' ) ) {
	function gymat_footer_html(){
		// Back-to-top link
		if ( GymatTheme::$options['back_to_top'] ){
			echo '<a href="#" class="scrollup"><i class="fas fa-angle-double-up"></i>' . esc_html__( 'TOP', 'gymat' ) . '</a>';
		}
	}	
}
/*Allow HTML for the kses post*/
function gymat_kses_allowed_html($tags, $context) {
    switch($context) {
        case 'social':
            $tags = array(
                'a' => array('href' => array()),
                'b' => array()
            );
            return $tags;
		case 'allow_link':
            $tags = array(
                'a' => array(
                    'class' => array(),
                    'href'  => array(),
                    'rel'   => array(),
                    'title' => array(),
					'target' => array(),
                ),
				'img' => array(
                    'alt'    => array(),
                    'class'  => array(),
                    'height' => array(),
                    'src'    => array(),
                    'srcset' => array(),
                    'width'  => array(),
                ),
                'b' => array()
            );
            return $tags;
		case 'allow_title':
            $tags = array(
				'a' => array(
                    'class' => array(),
                    'href'  => array(),
                    'rel'   => array(),
                    'title' => array(),
					'target' => array(),
                ),
                'span' => array(
                    'class' => array(),
                    'style' => array(),
                ),
                'b' => array()
            );
            return $tags;
			
        case 'alltext_allow':
            $tags = array(
                'a' => array(
                    'class' => array(),
                    'href'  => array(),
                    'rel'   => array(),
                    'title' => array(),
					'target' => array(),
                ),
                'abbr' => array(
                    'title' => array(),
                ),
                'b' => array(),
                'br' => array(),
                'blockquote' => array(
                    'cite'  => array(),
                ),
                'cite' => array(
                    'title' => array(),
                ),
                'code' => array(),
                'del' => array(
                    'datetime' => array(),
                    'title' => array(),
                ),
                'dd' => array(),
                'div' => array(
                    'class' => array(),
                    'title' => array(),
                    'style' => array(),
                    'id' 	=> array(),
                ),
                'dl' => array(),
                'dt' => array(),
                'em' => array(),
                'h1' => array(),
                'h2' => array(),
                'h3' => array(),
                'h4' => array(),
                'h5' => array(),
                'h6' => array(),
                'i' => array(
					'class' => array(),
				),
                'img' => array(
                    'alt'    => array(),
                    'class'  => array(),
                    'height' => array(),
                    'src'    => array(),
                    'srcset' => array(),
                    'width'  => array(),
                ),
                'li' => array(
                    'class' => array(),
                ),
                'ol' => array(
                    'class' => array(),
                ),
                'p' => array(
                    'class' => array(),
                ),
                'q' => array(
                    'cite' => array(),
                    'title' => array(),
                ),
                'span' => array(
                    'class' => array(),
                    'title' => array(),
                    'style' => array(),
                ),
                'strike' => array(),
                'strong' => array(),
                'ul' => array(
                    'class' => array(),
                ),
            );
            return $tags;
        default:
            return $tags;
    }
}
add_filter( 'wp_kses_allowed_html', 'gymat_kses_allowed_html', 10, 2);

add_filter( 'wp_kses_allowed_html', function( $tags ) {

    $tags['svg'] = array(
		'class'           => true,
		'aria-hidden'     => true,
		'aria-labelledby' => true,
		'role'            => true,
		'xmlns'           => true,
		'width'           => true,
		'height'          => true,
		'viewbox'         => true, // <= Must be lower case!
    );
    $tags['path'] = array(
        'd' => array(),
        'fill' => array(),
    );
    return $tags;

}, 10, 2);


/**
 * @param Wp_Query $query
 * @return mixed
 */
function advanced_search_query($query) {
    if($query->is_search()) {
        // category terms search.
        if (isset($_GET['category']) && !empty($_GET['category'])) {
            $query->set('tax_query', array(array(
                'taxonomy' => 'product_cat',
                'field' => 'slug',
                'terms' => array(sanitize_text_field($_GET['category'])))
            ));
        }    
    }
    return $query;
}
add_action('pre_get_posts', 'advanced_search_query', 1000);

/*social link to author profile page*/
add_action( 'show_user_profile', 'gymat_user_social_profile_fields' );
add_action( 'edit_user_profile', 'gymat_user_social_profile_fields' );

function gymat_user_social_profile_fields( $user ) { ?>

	<h3><?php esc_html_e( 'User Designation' , 'gymat' ); ?></h3>

	<table class="form-table">
		<tr>
			<th><label for="gymat_author_designation"><?php esc_html_e( 'Author Designation' , 'gymat' ); ?></label></th>
			<td><input type="text" name="gymat_author_designation" id="gymat_author_designation" value="<?php echo esc_attr( get_the_author_meta( 'gymat_author_designation', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Author Designation' , 'gymat' ); ?></span></td>
		</tr>
	</table>
	
	<h3><?php esc_html_e( 'Social profile information' , 'gymat' ); ?></h3>

	<table class="form-table">
		<tr>
			<th><label for="facebook"><?php esc_html_e( 'Facebook' , 'gymat' ); ?></label></th>
			<td><input type="text" name="facebook" id="facebook" value="<?php echo esc_attr( get_the_author_meta( 'gymat_facebook', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your facebook URL.' , 'gymat' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="twitter"><?php esc_html_e( 'Twitter' , 'gymat' ); ?></label></th>
			<td><input type="text" name="twitter" id="twitter" value="<?php echo esc_attr( get_the_author_meta( 'gymat_twitter', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Twitter username.' , 'gymat' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="linkedin"><?php esc_html_e( 'LinkedIn' , 'gymat' ); ?></label></th>
			<td><input type="text" name="linkedin" id="linkedin" value="<?php echo esc_attr( get_the_author_meta( 'gymat_linkedin', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your LinkedIn Profile' , 'gymat' ); ?></span></td>
		</tr>

		<tr>
			<th><label for="pinterest"><?php esc_html_e( 'Pinterest' , 'gymat' ); ?></label></th>
			<td><input type="text" name="pinterest" id="pinterest" value="<?php echo esc_attr( get_the_author_meta( 'gymat_pinterest', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Pinterest Profile' , 'gymat' ); ?></span></td>
		</tr>
	</table>
<?php }

add_action( 'personal_options_update', 'gymat_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'gymat_extra_profile_fields' );

function gymat_extra_profile_fields( $user_id ) {

	if ( !current_user_can( 'edit_user', $user_id ) )
		return false;

	update_user_meta( $user_id, 'gymat_facebook', esc_url_raw($_POST['facebook'] ));
	update_user_meta( $user_id, 'gymat_twitter', esc_url_raw($_POST['twitter']));
	update_user_meta( $user_id, 'gymat_linkedin', esc_url_raw($_POST['linkedin']));
	update_user_meta( $user_id, 'gymat_pinterest', esc_url_raw($_POST['pinterest']) );
	update_user_meta( $user_id, 'gymat_author_designation', sanitize_text_field($_POST['gymat_author_designation'] ));
}



if( ! function_exists( 'gymat_post_img_src' )){
	function gymat_post_img_src( $size = 'gymat-size1' ){
		$post_id  = get_the_ID();
		if ( has_post_thumbnail( $post_id ) ) {			
			$image_id = get_post_thumbnail_id( $post_id );			
			$image    = wp_get_attachment_image_src( $image_id, $size );
			return $image[0];
		} else {
			return;
		}
	}
}

/*Post Time & time format*/
if( ! function_exists( 'gymat_get_time' )){

	function gymat_get_time( $return = false ){

		$post = get_post();
		
		# Date is disabled globally ----------
		if( GymatTheme::$options['time_format'] == 'none' ){
			return false;
		}
		# Human Readable Post Dates ----------
		elseif(  GymatTheme::$options['time_format'] == 'modern' ){

			$time_now  = current_time( 'timestamp' );
			$post_time = get_the_time( 'U' ) ;
			$since = sprintf( esc_html__( '%s ago' , 'gymat' ), human_time_diff( $post_time, $time_now ) );			
		}
		else{
			$since = get_the_date();
		}

		$post_time = '<span class="date meta-item"><span class="fa fa-clock-o" aria-hidden="true"></span>  <span>'.$since.'</span></span>';

		if( $return ){
			return $post_time;
		}

		echo wp_kses( $post_time , 'alltext_allow' );
	}

}

function widgets_scripts( $hook ) {
    if ( 'widgets.php' != $hook ) {
        return;
    }
    wp_enqueue_style( 'wp-color-picker' );
	
}
add_action( 'admin_enqueue_scripts', 'widgets_scripts' );



/*
* for most use of the get_term cached 
* This is because all time it hits and single page provide data quickly
*/
function get_img( $img ){
	$img = get_stylesheet_directory_uri() . '/assets/img/' . $img;
	return $img;
}
function get_css( $file ){
	$file = get_stylesheet_directory_uri() . '/assets/css/' . $file . '.css';
	return $file;
}
function get_js( $file ){
	$file = get_stylesheet_directory_uri() . '/assets/js/' . $file . '.js';
	return $file;
}
function filter_content( $content ){
	// wp filters
	$content = wptexturize( $content );
	$content = convert_smilies( $content );
	$content = convert_chars( $content );
	$content = wpautop( $content );
	$content = shortcode_unautop( $content );

	// remove shortcodes
	$pattern= '/\[(.+?)\]/';
	$content = preg_replace( $pattern,'',$content );

	// remove tags
	$content = strip_tags( $content );

	return $content;
}

function get_current_post_content( $post = false ) {
	if ( !$post ) {
		$post = get_post();				
	}
	$content = has_excerpt( $post->ID ) ? $post->post_excerpt : $post->post_content;
	$content = filter_content( $content );
	return $content;
}

function cached_get_term_by( $field, $value, $taxonomy, $output = OBJECT, $filter = 'raw' ){
	// ID lookups are cached
	if ( 'id' == $field )
		return get_term_by( $field, $value, $taxonomy, $output, $filter );

	$cache_key = $field . '|' . $taxonomy . '|' . md5( $value );
	$term_id = wp_cache_get( $cache_key, 'get_term_by' );

	if ( false === $term_id ){
		$term = get_term_by( $field, $value, $taxonomy );
		if ( $term && ! is_wp_error( $term ) )
			wp_cache_set( $cache_key, $term->term_id, 'get_term_by' );
		else
			wp_cache_set( $cache_key, 0, 'get_term_by' ); // if we get an invalid value, let's cache it anyway
	} else {
		$term = get_term( $term_id, $taxonomy, $output, $filter );
	}

	if ( is_wp_error( $term ) )
		$term = false;

	return $term;
}

/*for avobe reason*/
function cached_get_term_link( $term, $taxonomy = null ){
	// ID- or object-based lookups already result in cached lookups, so we can ignore those.
	if ( is_numeric( $term ) || is_object( $term ) ){
		return get_term_link( $term, $taxonomy );
	}

	$term_object = cached_get_term_by( 'slug', $term, $taxonomy );
	return get_term_link( $term_object );
}


/*only to show the first category in the post - primary category*/
function gymat_if_term_exists( $term, $taxonomy = '', $parent = null ){
	if ( null !== $parent ){
		return term_exists( $term, $taxonomy, $parent );
	}

	if ( ! empty( $taxonomy ) ){
		$cache_key = $term . '|' . $taxonomy;
	}else{
		$cache_key = $term;
	}

	$cache_value = wp_cache_get( $cache_key, 'term_exists' );

	//term_exists frequently returns null, but (happily) never false
	if ( false  === $cache_value ){
		$term_exists = term_exists( $term, $taxonomy );
		wp_cache_set( $cache_key, $term_exists, 'term_exists' );
	}else{
		$term_exists = $cache_value;
	}

	if ( is_wp_error( $term_exists ) )
		$term_exists = null;

	return $term_exists;
}


if( ! function_exists( 'gymat_get_primary_category' )){

	function gymat_get_primary_category() {

		if( get_post_type() != 'post' ) {
			return;
		}

		# Get the first assigned category ----------
			$get_the_category = get_the_category();
			$primary_category = array( $get_the_category[0] );

		if( ! empty( $primary_category[0] )) {
			return $primary_category;
		}
	}
}

/*only to show the first category in the post - primary category ID*/
if( ! function_exists( 'gymat_get_primary_category_id' )){

	function gymat_get_primary_category_id(){

		$primary_category = gymat_get_primary_category();

		if( ! empty( $primary_category[0]->term_id )){
			return $primary_category[0]->term_id;
		}

		return false;
	}
}

// Head Script
if( !function_exists( 'gymat_head' ) ) {
	function gymat_head(){
		// Hide preloader if js is disabled
		echo '<noscript><style>#preloader{display:none;}</style></noscript>';
	}	
}
add_action( 'wp_head', 'gymat_head', 1 );

//find the post type function 
if ( ! function_exists ( 'gymat_post_type' ) ) {
	function gymat_post_type() {
		$gymat_post_type_var =get_post_type( get_the_ID());
		echo esc_html( $gymat_post_type_var );
	}
}

/*next previous post links*/
if ( !function_exists( 'gymat_post_links_next_prev' ) ) {
	function gymat_post_links_next_prev() { ?>
	<div class="row no-gutters divider post-navigation prev-next-post">
		<?php if ( !empty( get_next_post_link())){ ?>
			<div class=" col-lg-6 col-md-6 col-sm-6 col-12  <?php if ( empty( get_previous_post_link())){ ?>-offset-md-6<?php } ?> <?php if ( is_rtl() ){ echo esc_attr( 'text-left' ); } else { echo esc_attr( 'text-left' ); } ?>">
				<div class="pad-lr-15">
					<div class="content next">
						<div class="nav-link">
							<span class="next-article">
								<svg width="21" height="12" viewBox="0 0 21 12" fill="none" xmlns="http://www.w3.org/2000/svg">
									<path fill-rule="evenodd" clip-rule="evenodd" d="M21 6C21 5.77272 20.9129 5.55474 20.758 5.39402C20.603 5.2333 20.3928 5.14301 20.1737 5.14301L2.82257 5.14301L6.37084 1.46482C6.44767 1.38514 6.50861 1.29055 6.55019 1.18644C6.59177 1.08233 6.61317 0.970755 6.61317 0.858071C6.61317 0.745388 6.59177 0.633808 6.55019 0.529702C6.50861 0.425596 6.44767 0.331003 6.37084 0.251324C6.29401 0.171645 6.2028 0.108439 6.10242 0.0653168C6.00204 0.0221947 5.89445 6.51552e-07 5.78579 6.32555e-07C5.67714 6.13558e-07 5.56955 0.0221946 5.46917 0.0653167C5.36879 0.108439 5.27758 0.171644 5.20075 0.251324L0.242767 5.39325C0.165813 5.47286 0.104759 5.56743 0.0631015 5.67154C0.0214437 5.77566 1.06878e-06 5.88728 1.04907e-06 6C1.02936e-06 6.11272 0.0214437 6.22434 0.0631014 6.32846C0.104759 6.43257 0.165813 6.52714 0.242767 6.60675L5.20075 11.7487C5.35591 11.9096 5.56636 12 5.78579 12C6.00523 12 6.21567 11.9096 6.37083 11.7487C6.526 11.5878 6.61317 11.3695 6.61317 11.1419C6.61317 10.9144 6.526 10.6961 6.37084 10.5352L2.82257 6.85699L20.1737 6.85699C20.3928 6.85699 20.603 6.7667 20.758 6.60599C20.9129 6.44527 21 6.22729 21 6Z" fill="#FF0336"/>
								</svg><?php next_post_link( '%link', esc_html__('Previous Article' , 'gymat' ) );?>
							</span>
						</div>
						<?php next_post_link( '<h5 class="post-nav-title">%link</h5>' ); ?>
					</div>
				</div>			
			</div>
		<?php } ?>
		
		<?php if ( !empty( get_previous_post_link())){ ?>
			<div class="col-lg-6 col-md-6 col-sm-6 col-12  <?php if ( empty( get_next_post_link())){ ?>offset-md-6<?php } ?> <?php if ( is_rtl() ){ echo esc_attr( 'text-right' ); } else { echo esc_attr( 'text-right' ); } ?>">
				<div class="pad-lr-15">
					<div class="content prev">
						<div class="nav-link">
							<span class="prev-article">
								<?php previous_post_link( '%link', esc_html__('Next Article' , 'gymat' ) );?><svg width="21" height="12" viewBox="0 0 21 12" fill="none" xmlns="http://www.w3.org/2000/svg">
								<path fill-rule="evenodd" clip-rule="evenodd" d="M-1.04907e-06 6C-1.08881e-06 5.77272 0.0870579 5.55474 0.242026 5.39402C0.396992 5.2333 0.607173 5.14301 0.826329 5.14301L18.1774 5.14301L14.6292 1.46482C14.5523 1.38514 14.4914 1.29055 14.4498 1.18644C14.4082 1.08233 14.3868 0.970755 14.3868 0.858072C14.3868 0.745388 14.4082 0.633807 14.4498 0.529701C14.4914 0.425595 14.5523 0.331003 14.6292 0.251324C14.706 0.171644 14.7972 0.108439 14.8976 0.0653163C14.998 0.022195 15.1056 1.03062e-06 15.2142 1.01162e-06C15.3229 9.92623e-07 15.4304 0.0221949 15.5308 0.0653162C15.6312 0.108438 15.7224 0.171644 15.7992 0.251324L20.7572 5.39325C20.8342 5.47286 20.8952 5.56743 20.9369 5.67154C20.9786 5.77566 21 5.88728 21 6C21 6.11272 20.9786 6.22434 20.9369 6.32846C20.8952 6.43257 20.8342 6.52714 20.7572 6.60675L15.7992 11.7487C15.6441 11.9096 15.4336 12 15.2142 12C14.9948 12 14.7843 11.9096 14.6292 11.7487C14.474 11.5878 14.3868 11.3695 14.3868 11.1419C14.3868 10.9144 14.474 10.6961 14.6292 10.5352L18.1774 6.85699L0.826329 6.85699C0.607173 6.85699 0.396993 6.7667 0.242026 6.60598C0.087058 6.44527 -1.00933e-06 6.22729 -1.04907e-06 6Z" fill="#FF0336"/>
								</svg>
							</span>
						</div>
						<?php previous_post_link('<h5 class="post-nav-title">%link</h5>'); ?>
					</div>
				</div>
			</div>
		<?php } ?>
	</div>
<?php }
}

/*Remove the archive label*/
function gymat_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
        $title = single_tag_title( '', false );
    } elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    } elseif ( is_tax() ) {
        $title = single_term_title( '', false );
    }
  
    return $title;
}
 
add_filter( 'get_the_archive_title', 'gymat_archive_title' );

function w3c_validator(){
	/*----------------------------------------------------------------------------------------------------*/
	/*  W3C validator passing code
	/*----------------------------------------------------------------------------------------------------*/
	ob_start( function( $buffer ){
		$buffer = str_replace( array( '<script type="text/javascript">', "<script type='text/javascript'>" ), '<script>', $buffer );
		return $buffer;
	});
	ob_start( function( $buffer2 ){
		$buffer2 = str_replace( array( "<script type='text/javascript' src" ), '<script src', $buffer2 );
		return $buffer2;
	});
	ob_start( function( $buffer3 ){
		$buffer3 = str_replace( array( 'type="text/css"', "type='text/css'", 'type="text/css"', ), '', $buffer3 );
		return $buffer3;
	});
	ob_start( function( $buffer4 ){
		$buffer4 = str_replace( array( '<iframe frameborder="0" scrolling="no" marginheight="0" marginwidth="0"', ), '<iframe', $buffer4 );
		return $buffer4;
	});
	ob_start( function( $buffer5 ){
		$buffer5 = str_replace( array( 'aria-required="true"', ), '', $buffer5 );
		return $buffer5;
	});
}

add_action( 'template_redirect', 'w3c_validator' );








