<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

if( ! function_exists( 'gymat_related_trainer' )){
	
	function gymat_related_trainer(){
		$thumb_size = 'gymat-size4';
		$post_id = get_the_id();	
		$number_of_avail_post = '';
		$current_post = array( $post_id );
		$title_length = GymatTheme::$options['related_trainer_title_limit'] ? GymatTheme::$options['related_trainer_title_limit'] : '';
		$related_post_number = GymatTheme::$options['related_trainer_number'];
		
		$content 	= get_the_content();
		$content 	= apply_filters( 'the_content', $content );
		
		$trainer_related_title  = get_post_meta( get_the_ID(), 'trainer_related_title', true );

		# Making ready to the Query ...
		$query_type = GymatTheme::$options['related_post_query'];

		$args = array(
			'post_type'				 => 'gymat_trainer',
			'post__not_in'           => $current_post,
			'posts_per_page'         => $related_post_number,
			'no_found_rows'          => true,
			'post_status'            => 'publish',
			'ignore_sticky_posts'    => true,
			'update_post_term_cache' => false,
		);

		# Checking Related Posts Order ----------
		if( GymatTheme::$options['related_post_sort'] ){

			$post_order = GymatTheme::$options['related_post_sort'];

			if( $post_order == 'rand' ){

				$args['orderby'] = 'rand';
			}
			elseif( $post_order == 'views' ){

				$args['orderby']  = 'meta_value_num';
				$args['meta_key'] = 'gymat_views';
			}
			elseif( $post_order == 'popular' ){

				$args['orderby'] = 'comment_count';
			}
			elseif( $post_order == 'modified' ){

				$args['orderby'] = 'modified';
				$args['order']   = 'ASC';
			}
			elseif( $post_order == 'recent' ){

				$args['orderby'] = '';
				$args['order']   = '';
			}
		}


		# Get related posts by author ----------
		if( $query_type == 'author' ){
			$args['author'] = get_the_author_meta( 'ID' );
		}

		# Get related posts by tags ----------
		elseif( $query_type == 'tag' ){
			$tags_ids  = array();
			$post_tags = get_the_terms( $post_id, 'post_tag' );

			if( ! empty( $post_tags ) ){
				foreach( $post_tags as $individual_tag ){
					$tags_ids[] = $individual_tag->term_id;
				}

				$args['tag__in'] = $tags_ids;
			}
		}

		# Get related posts by categories ----------
		else{
			
			$terms = get_the_terms( $post_id, 'gymat_trainer_category' );
			if($terms ){
				if ( $terms && ! is_wp_error( $terms ) ) {
			 
					$port_cat_links = array();
				 
					foreach ( $terms as $term ) {
						$port_cat_links[] = $term->term_id;
					}
				}
				
				
				$args['tax_query'] = array (
					array (
						'taxonomy' => 'gymat_trainer_category',
						'field'    => 'ID',
						'terms'    => $port_cat_links,
					)
				);
			}
			
		}

		# Get the posts ----------
		$related_query = new wp_query( $args );
		/*the_carousel*/
		
		
		$count_post = $related_query->post_count;
		if ( $count_post < 4 ) {
			$number_of_avail_post = false;
		} else {
			$number_of_avail_post = true;
		}
		$swiper_data=array(
			'slidesPerView' 	=>2,
			'centeredSlides'	=>false,
			'loop'				=>true,
			'spaceBetween'		=>20,
			'slideToClickedSlide' =>true,
			'slidesPerGroup' => 1,
			'autoplay'				=>array(
				'delay'  => 1,
			),
			'speed'      =>500,
			'breakpoints' =>array(
				'0'    =>array('slidesPerView' =>1),
				'576'    =>array('slidesPerView' =>2),
				'768'    =>array('slidesPerView' =>2),
				'992'    =>array('slidesPerView' =>2),
				'1200'    =>array('slidesPerView' =>3),				
				'1600'    =>array('slidesPerView' =>3)				
			),
			'auto'   =>false
		);

		$swiper_data = json_encode( $swiper_data );
		
		
		if( $related_query->have_posts() ) { ?>
		
		<div class="trainer-default trainer-multi-layout-2 trainer-grid-style2  rt-related-post trainer-related-post">
			<div class="rt-related-slider" data-xld = '<?php echo esc_attr($swiper_data);?>'>
				<div class="section-title">
				<?php if ( GymatTheme::$options['trainer_related_title'] ) { ?>
				<h3 class="related-title"><?php echo wp_kses( GymatTheme::$options['trainer_related_title'] , 'alltext_allow' );?></h3><?php } ?>
					<?php if ( $count_post > 3 ){ ?>
						<div class="swiper-button">
							<div class="swiper-button-prev"><i class="fas fa-chevron-left"></i></div>
							<div class="swiper-button-next"><i class="fas fa-chevron-right"></i></div>
						</div>
					<?php } ?>
					
				</div>
				
				<div class="swiper-wrapper">
					<?php
						while ( $related_query->have_posts() ) {
						$related_query->the_post();
						$trimmed_title = wp_trim_words( get_the_title(), $title_length, '' );
						$id = get_the_ID();
						$socials       	= get_post_meta( $id, 'gymat_trainer_socials', true );
						$social_fields 	= GymatTheme_Helper::trainer_socials();
						$position   	= get_post_meta( $id, 'gymat_trainer_designation', true );
					?>
						<div class="swiper-slide">						
							<div class="trainer-item">
								<div class="trainer-thumb">
									<a href="<?php the_permalink();?>">
									<?php
									if ( has_post_thumbnail() ){
										the_post_thumbnail( $thumb_size );
									}
									else {
										if ( !empty( GymatTheme::$options['no_preview_image']['id'] ) ) {
											echo wp_get_attachment_image( GymatTheme::$options['no_preview_image']['id'], $thumb_size );
										}
										else {
											echo '<img class="wp-post-image" src="' . GymatTheme_Helper::get_img( 'noimage_400X400.jpg' ) . '" alt="'.get_the_title().'">';
										}
									}
									?>
									</a>			
								</div>
								<div class="trainer-info">
									<div class="trainer-content">
										<div class="trainer-icon-shape">
											<img src="<?php echo GYMAT_ASSETS_URL . 'element/shape-40.png'; ?>" alt="<?php esc_attr_e( 'shape40','gymat' ); ?>">
											<a href="#" class="rt-icon"><i class="fas fa-angle-up"></i></a>
										</div>
										<h3 class="trainer-title"><a href="<?php the_permalink();?>"><?php echo wp_kses( $trimmed_title , 'alltext_allow' ); ?></a></h3>
										<?php if(GymatTheme::$options['related_trainer_position']){ ?>
											<div class="trainer-designation"><?php echo esc_html( $position );?></div>
										<?php } ?>
										<?php if(GymatTheme::$options['related_trainer_social']){ ?>
											<?php if ( !empty( $socials )) { ?>
													<div class="trainer-socials">
														<ul class="trainer-social-icon">
															<?php foreach ( $socials as $key => $social ): ?>
																<?php if ( !empty( $social ) ): ?>
																	<li><a target="_blank" href="<?php echo esc_url( $social );?>"><i class="fab <?php echo esc_attr( $social_fields[$key]['icon'] );?>" aria-hidden="true"></i></a>
																	</li>
																<?php endif; ?>
															<?php endforeach; ?>
														</ul>
													</div>
										<?php   } 
												}
										?>
									</div>
								</div>
							</div>
						</div>
					<?php } ?>
				</div>
			</div>
		</div>
		<?php }
		wp_reset_postdata();
	}
}
?>