<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

use Elementor\Plugin; 


function gymat_get_maybe_rtl( $filename ){
	$file = get_template_directory_uri() . '/assets/';
	if ( is_rtl() ) {
		return $file . 'rtl-css/' . $filename;
	}
	else {
		return $file . 'css/' . $filename;
	}
}
add_action( 'wp_enqueue_scripts','gymat_enqueue_high_priority_scripts', 1500 );
function gymat_enqueue_high_priority_scripts() {
	if ( is_rtl() ) {
		wp_enqueue_style( 'rtlcss', GYMAT_CSS_URL . 'rtl.css', array(), GYMAT_VERSION );
	}
}


//elementor animation dequeue
add_action('elementor/frontend/after_enqueue_scripts', function(){
    wp_deregister_style( 'e-animations' );
    wp_dequeue_style( 'e-animations' );
});



add_action( 'wp_enqueue_scripts', 'gymat_register_scripts', 12 );
if ( !function_exists( 'gymat_register_scripts' ) ) {
	function gymat_register_scripts(){
		wp_deregister_style( 'font-awesome' );
        wp_deregister_style( 'layerslider-font-awesome' );
        wp_deregister_style( 'yith-wcwl-font-awesome' );

		/*CSS*/
				
		wp_register_style( 'magnific-popup',     gymat_get_maybe_rtl('magnific-popup.css'), array(), GYMAT_VERSION );
		wp_register_style( 'animate',        	 gymat_get_maybe_rtl('animate.min.css'), array(), GYMAT_VERSION );
		
		
		wp_register_script( 'appear',         	 GYMAT_JS_URL . 'appear.min.js', array( 'jquery' ), GYMAT_VERSION, true );

		//piechart
		wp_register_script( 'easypiechart', GYMAT_JS_URL . 'jquery.easypiechart.min.js', array( 'jquery'), GYMAT_VERSION, true );

		wp_register_script( 'rt-parallax',   	 GYMAT_JS_URL . 'rt-parallax.js', array( 'jquery' ), GYMAT_VERSION, true );

		// magnific popup
		wp_register_script( 'magnific-popup',    GYMAT_JS_URL . 'jquery.magnific-popup.min.js', array( 'jquery' ), GYMAT_VERSION, true );

		// theia sticky
		wp_register_script( 'theia-sticky',    	 GYMAT_JS_URL . 'theia-sticky-sidebar.min.js', array( 'jquery' ), GYMAT_VERSION, true );
		
		wp_register_script( 'isotope-pkgd',      GYMAT_JS_URL . 'isotope.pkgd.min.js', array( 'jquery' ), GYMAT_VERSION, true );
		
		

		// vanilla tilt js
		wp_register_script( 'vanilla-tilt',   	 GYMAT_JS_URL . 'vanilla-tilt.min.js', array( 'jquery' ), GYMAT_VERSION, true );

		//countdown js
		wp_register_script( 'countdown',   	 GYMAT_JS_URL . 'countdown.min.js', array( 'jquery' ), GYMAT_VERSION, true );

		// wow js
		wp_register_script( 'rt-wow',   		 GYMAT_JS_URL . 'wow.min.js', array( 'jquery' ), GYMAT_VERSION, true );

		wp_register_script( 'swiper',   		 GYMAT_JS_URL . 'swiper.min.js', array( 'jquery' ), GYMAT_VERSION, true );
	}
}

add_action( 'wp_enqueue_scripts', 'gymat_enqueue_scripts', 15 );
if ( !function_exists( 'gymat_enqueue_scripts' ) ) {
	function gymat_enqueue_scripts() {
		$dep = array( 'jquery' );
		/*CSS*/
		// Google fonts
		wp_enqueue_style( 'gymat-gfonts', 		GymatTheme_Helper::fonts_url(), array(), GYMAT_VERSION );
		// Bootstrap CSS  //@rtl
		wp_enqueue_style( 'bootstrap', 			gymat_get_maybe_rtl('bootstrap.min.css'), array(), GYMAT_VERSION );
		
		// Flaticon CSS
		wp_enqueue_style( 'flaticon-gymat',    GYMAT_ASSETS_URL . 'fonts/flaticon-gymat/flaticon.css', array(), GYMAT_VERSION );

		

		elementor_scripts();
		//Video popup
		wp_enqueue_style( 'magnific-popup' );


		// font-awesome CSS
		wp_enqueue_style( 'font-awesome',       GYMAT_CSS_URL . 'font-awesome.min.css', array(), GYMAT_VERSION );
		// animate CSS
		wp_enqueue_style( 'animate',            gymat_get_maybe_rtl('animate.min.css'), array(), GYMAT_VERSION );

		// main CSS // @rtl
		wp_enqueue_style( 'gymat-default',    	gymat_get_maybe_rtl('default.css'), array(), GYMAT_VERSION );
		// vc modules css
		wp_enqueue_style( 'gymat-elementor',   gymat_get_maybe_rtl('elementor.css'), array(), GYMAT_VERSION );


		wp_enqueue_style( 'gymat-rt-animate',   gymat_get_maybe_rtl('rt-animate.css'), array(), GYMAT_VERSION );
			
		// Style CSS
		wp_enqueue_style( 'gymat-style',     	gymat_get_maybe_rtl('style.css'), array(), GYMAT_VERSION );
		
		// Template Style
		wp_add_inline_style( 'gymat-style',gymat_template_style() );

	
		// bootstrap js
		wp_enqueue_script( 'bootstrap',         GYMAT_JS_URL . 'bootstrap.min.js', array( 'jquery' ), GYMAT_VERSION, true );
		
		// Comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
		
		wp_enqueue_script( 'theia-sticky' );
		wp_enqueue_script( 'magnific-popup' );
		wp_enqueue_script( 'rt-wow' );
		wp_enqueue_script( 'rt-parallax' );
		wp_enqueue_script( 'appear' );
		wp_enqueue_script( 'vanilla-tilt' );
		wp_enqueue_script( 'countdown' );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'gymat-main',    	GYMAT_JS_URL . 'main.js', $dep , GYMAT_VERSION, true );
		
		if( !empty( GymatTheme::$options['logo'] ) ) {
			$logo_dark = wp_get_attachment_image( GymatTheme::$options['logo'], 'full' );
			$logo = $logo_dark;
		}else {
			$logo = "<img width='92' height='39' loading='lazy' class='logo-small' src='" . GYMAT_IMG_URL . 'logo.svg' . "' alt='" . esc_attr( get_bloginfo('name') ) . "'>"; 
		}
		
		// info menu bar
		$html = '';
		ob_start();
		get_template_part( 'template-parts/header/icon', 'menubar' );
		$html .= ob_get_clean();
		
		// localize script
		$gymat_localize_data = array(
			'stickyMenu' 	=> GymatTheme::$options['sticky_menu'],
			'meanWidth'    => GymatTheme::$options['resmenu_width'],
			'siteLogo'   	=> '<a href="' . esc_url( home_url( '/' ) ) . '" alt="' . esc_attr( get_bloginfo( 'title' ) ) . '">' . esc_html ( $logo ) . '</a>' . $html,
			'extraOffset' => GymatTheme::$options['sticky_menu'] ? 70 : 0,
			'extraOffsetMobile' => GymatTheme::$options['sticky_menu'] ? 52 : 0,
			'rtl' => is_rtl()?'yes':'no',
			
			// CountDown
			'month'	         => esc_html__('Month' , 'gymat'),
			'day'	         => esc_html__('Day' , 'gymat'),
			'hour'	         => esc_html__('Hour' , 'gymat'),
			'minute'         => esc_html__('Minute' , 'gymat'),
			'second'         => esc_html__('Second' , 'gymat'),
			'close_text'     => esc_html__('close' , 'gymat'),

			// Ajax
			'ajaxURL' => admin_url('admin-ajax.php'),
			'nonce' => wp_create_nonce( 'gymat-nonce' )
		);
		wp_localize_script( 'gymat-main', 'gymatObj', $gymat_localize_data );
	}	
}

function elementor_scripts() {
	
	if ( !did_action( 'elementor/loaded' ) ) {
		return;
	}
	
	if ( \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
		// do stuff for preview
		wp_enqueue_script( 'appear' );		
		wp_enqueue_script( 'rt-wow' );
		wp_enqueue_script( 'vanilla-tilt' );
		wp_enqueue_script( 'countdown' );
	} 
}

add_action( 'wp_enqueue_scripts', 'gymat_high_priority_scripts', 1500);
if ( !function_exists( 'gymat_high_priority_scripts' ) ) {
	function gymat_high_priority_scripts() {
		// Dynamic style
		GymatTheme_Helper::dynamic_internal_style();
	}
}

function gymat_template_style(){
	ob_start();
	?>
	
	.entry-banner {
		<?php if ( GymatTheme::$bgtype == 'bgcolor' ): ?>
			background-color: <?php echo esc_html( GymatTheme::$bgcolor );?>;
		<?php else: ?>
			background-image: url(<?php echo esc_url( GymatTheme::$bgimg );?>);
			background-repeat: no-repeat;
			background-size: cover;
			background-position:bottom;
		<?php endif; ?>
	}

	.content-area {
		padding-top: <?php echo esc_html( GymatTheme::$padding_top );?>px; 
		padding-bottom: <?php echo esc_html( GymatTheme::$padding_bottom );?>px;
	}
	<?php if( isset( GymatTheme::$pagebgimg ) || isset( GymatTheme::$pagebgcolor ) ) { ?>
	#page .content-area {
		background-image: url( <?php echo GymatTheme::$pagebgimg; ?> );
		background-color: <?php echo GymatTheme::$pagebgcolor; ?>;
	}
	<?php } ?>
	.error-page-area .error-page-content {		 
		background-color: <?php echo esc_html( GymatTheme::$options['error_bodybg'] );?>;
	}
	
	<?php
	return ob_get_clean();
}

function load_custom_wp_admin_script_gutenberg() {
	wp_enqueue_style( 'gymat-gfonts', GymatTheme_Helper::fonts_url(), array(), GYMAT_VERSION );
	// font-awesome CSS
	wp_enqueue_style( 'font-awesome',       GYMAT_CSS_URL . 'font-awesome.min.css', array(), GYMAT_VERSION );
	// Flaticon CSS
	wp_enqueue_style( 'flaticon-gymat',    GYMAT_ASSETS_URL . 'fonts/flaticon-gymat/flaticon.css', array(), GYMAT_VERSION );
}
add_action( 'admin_enqueue_scripts', 'load_custom_wp_admin_script_gutenberg', 1 );

function load_custom_wp_admin_script() {
	wp_enqueue_style( 'gymat-admin-style',  GYMAT_CSS_URL . 'admin-style.css', false, GYMAT_VERSION );
	wp_enqueue_script( 'gymat-admin-main',  GYMAT_JS_URL . 'admin.main.js', false, GYMAT_VERSION, true );
	
}
add_action( 'admin_enqueue_scripts', 'load_custom_wp_admin_script' );
